@@ -1,9 +1,9 @@
 package Spreadsheet::ParseXLSX;
 our $AUTHORITY = 'cpan:DOY';
-$Spreadsheet::ParseXLSX::VERSION = '0.17';
+$Spreadsheet::ParseXLSX::VERSION = '0.18';
 use strict;
 use warnings;
-use 5.010;
+use 5.008;
 # ABSTRACT: parse XLSX files
 
 use Archive::Zip;
@@ -86,13 +86,17 @@ sub _parse_workbook {
 
     my @sheets = map {
         my $idx = $_->att('r:id');
-        my $sheet = Spreadsheet::ParseExcel::Worksheet->new(
-            Name     => $_->att('name'),
-            _Book    => $workbook,
-            _SheetNo => $idx,
-        );
-        $self->_parse_sheet($sheet, $files->{sheets}{$idx});
-        $sheet
+        if ($files->{sheets}{$idx}) {
+          my $sheet = Spreadsheet::ParseExcel::Worksheet->new(
+              Name     => $_->att('name'),
+              _Book    => $workbook,
+              _SheetNo => $idx,
+          );
+          $self->_parse_sheet($sheet, $files->{sheets}{$idx});
+          ($sheet)
+        } else {
+          ()
+        }
     } $files->{workbook}->find_nodes('//sheets/sheet');
 
     $workbook->{Worksheet}  = \@sheets;
@@ -160,7 +164,8 @@ sub _parse_sheet {
                 my ($twig, $margin) = @_;
                 map {
                     my $key = "\u${_}Margin";
-                    $sheet->{$key} = $margin->att($_) // 0
+                    $sheet->{$key} = defined $margin->att($_)
+                                    ? $margin->att($_) : 0
                 } qw(left right top bottom header footer);
 
                 $twig->purge;
@@ -168,9 +173,13 @@ sub _parse_sheet {
 
             'pageSetup' => sub {
                 my ($twig, $setup) = @_;
-                $sheet->{Scale} = $setup->att('scale') // 100;
-                $sheet->{Landscape} = ($setup->att('orientation') // '') ne 'landscape';
-                $sheet->{PaperSize} = $setup->att('paperSize') // 1;
+                $sheet->{Scale} = defined $setup->att('scale')
+                                ? $setup->att('scale')
+                                : 100;
+                $sheet->{Landscape} = ($setup->att('orientation') || '') ne 'landscape';
+                $sheet->{PaperSize} = defined $setup->att('paperSize')
+                                    ? $setup->att('paperSize')
+                                    : 1;
                 $sheet->{PageStart} = $setup->att('firstPageNumber');
                 $sheet->{UsePage} = $self->_xml_boolean($setup->att('useFirstPageNumber'));
                 $sheet->{HorizontalDPI} = $setup->att('horizontalDpi');
@@ -205,8 +214,10 @@ sub _parse_sheet {
             'sheetFormatPr' => sub {
                 my ( $twig, $format ) = @_;
 
-                $default_row_height   //= $format->att('defaultRowHeight');
-                $default_column_width //= $format->att('baseColWidth');
+                $default_row_height   = $format->att('defaultRowHeight')
+                  unless defined $default_row_height;
+                $default_column_width = $format->att('baseColWidth')
+                  unless defined $default_column_width;
 
                 $twig->purge;
             },
@@ -861,7 +872,7 @@ Spreadsheet::ParseXLSX - parse XLSX files
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
@@ -939,8 +950,6 @@ although this may have other consequences such as memory leaks.
 
 =item Intra-cell formatting is discarded
 
-=item Diagonal border styles are ignored
-
 =back
 
 In addition, there are still a few areas which are not yet implemented (the
